@@ -5,6 +5,7 @@ import datetime
 import logging
 import subprocess
 import tempfile
+from collections import defaultdict
 from dataclasses import dataclass
 from pathlib import Path
 from typing import Dict, Optional, Tuple
@@ -25,7 +26,7 @@ logger = logging.getLogger(__name__)
 
 ActualWorkingHoursDict = Dict[Tuple[datetime.date, str, str], float]
 """実績作業時間の日ごとの情報を格納する辞書
-key: (date, organization_member_id, job_id), value: 実績作業時間
+key: (date, workspace_member_id, job_id), value: 実績作業時間
 """
 
 
@@ -45,36 +46,38 @@ JobIdAnnofabProjectIdDict = Dict[str, str]
 
 
 class ListLabor:
-    def __init__(self, annowork_service: AnnoworkResource, organization_id: str):
+    def __init__(self, annowork_service: AnnoworkResource, workspace_id: str):
         self.annowork_service = annowork_service
-        self.organization_id = organization_id
+        self.workspace_id = workspace_id
 
-        self.all_job_list = self.annowork_service.api.get_jobs(self.organization_id)
+        self.all_job_list = self.annowork_service.api.get_jobs(self.workspace_id)
 
         # Annofabが日本時間に固定されているので、それに合わせて timezone_offset_hours を指定する。
         self.list_actual_working_time_obj = ListActualWorkingTime(
             annowork_service=annowork_service,
-            organization_id=organization_id,
+            workspace_id=workspace_id,
             timezone_offset_hours=TIMEZONE_OFFSET_HOURS,
         )
 
     def get_job_id_annofab_project_id_dict_from_annofab_project_id(
         self, annofab_project_id_list: list[str]
     ) -> JobIdAnnofabProjectIdDict:
-        annofab_project_id_dict = {
-            get_annofab_project_id_from_job(job): job["job_id"]
-            for job in self.all_job_list
-            if get_annofab_project_id_from_job(job) is not None
-        }
+        # オーダを減らすため、事前にdictを作成する
+        annofab_project_id_dict: dict[str, list[str]] = defaultdict(list)
+        for job in self.all_job_list:
+            af_project_id = get_annofab_project_id_from_job(job)
+            if af_project_id is not None:
+                annofab_project_id_dict[af_project_id].append(job["job_id"])
 
         result = {}
         for annofab_project_id in annofab_project_id_list:
-            job_id = annofab_project_id_dict.get(annofab_project_id)
-            if job_id is None:
+            job_id_list = annofab_project_id_dict.get(annofab_project_id)
+            if job_id_list is None:
                 logger.warning(f"ジョブの外部連携情報に、AnnoFabのプロジェクトID '{annofab_project_id}' を表すURLが設定されたジョブは見つかりませんでした。")
                 continue
 
-            result[job_id] = annofab_project_id
+            for job_id in job_id_list:
+                result[job_id] = annofab_project_id
 
         return result
 
@@ -169,7 +172,7 @@ def visualize_statistics(temp_dir: Path, args):
     annowork_service = build_annoworkapi(args)
     job_id_list = get_list_from_args(args.job_id)
     annofab_project_id_list = get_list_from_args(args.annofab_project_id)
-    main_obj = ListLabor(annowork_service, args.organization_id)
+    main_obj = ListLabor(annowork_service, args.workspace_id)
     annofab_labor_list = main_obj.get_annofab_labor_list(
         job_id_list=job_id_list,
         annofab_project_id_list=annofab_project_id_list,
@@ -228,11 +231,11 @@ def main(args):
 
 def parse_args(parser: argparse.ArgumentParser):
     parser.add_argument(
-        "-org",
-        "--organization_id",
+        "-w",
+        "--workspace_id",
         type=str,
         required=True,
-        help="対象の組織ID",
+        help="対象のワークスペースID",
     )
 
     job_id_group = parser.add_mutually_exclusive_group(required=True)
