@@ -2,7 +2,7 @@ import argparse
 from typing import Optional
 
 import annoworkcli
-import annoworkcli.job.change_job_status
+import annoworkcli.job.change_job_properties
 import annoworkcli.job.delete_job
 import annoworkcli.job.list_job
 
@@ -12,7 +12,7 @@ def parse_args(parser: argparse.ArgumentParser):
     subparsers = parser.add_subparsers(dest="subcommand_name")
 
     # サブコマンドの定義
-    annoworkcli.job.change_job_status.add_parser(subparsers)
+    annoworkcli.job.change_job_properties.add_parser(subparsers)
     annoworkcli.job.delete_job.add_parser(subparsers)
     annoworkcli.job.list_job.add_parser(subparsers)
 
